@@ -108,7 +108,7 @@ def save_resource():
     data['state'] = 'active'
     data['url_type'] = 'upload'
     resource_id = data.get('id')
-    if not resource_id:
+    if not resource_id or request.files.get('upload'):
         data['upload'] = request.files['upload']
     metadata = data['metadata']
     del data['metadata']
@@ -154,7 +154,7 @@ def delete_resource(resource_id):
         'for_edit': True,
     }
     try:
-        toolkit.check_access('package_create', context)
+        toolkit.check_access('resource_delete', context)
     except toolkit.NotAuthorized:
         toolkit.abort(401, toolkit._('Unauthorized to create a dataset'))
     data = {
@@ -166,7 +166,7 @@ def delete_resource(resource_id):
         'package': None
     }
     try:
-        resource = get_action('resource_patch')(context, data)
+        resource = get_action('resource_delete')(context, data)
     except ValidationError as e:
         data_response['errors'] = e.error_dict
         data_response['error_summary'] = e.error_summary
@@ -433,7 +433,7 @@ def entity_diagram_show(package_id):
         nodes.append(encoded_string[start_tag:start_tag + close_tag + 4])
     for resource in package.resources:
         name = resource.name
-        id = resource.to_dict()['tableschema']['id']
+        id = resource.to_dict()['id']
         site_url = config.get('ckan.site_url')
         if site_url.endswith('/'):
             url = f"{site_url}dataset/{package['name']}/resource/{id}"
