@@ -50,8 +50,8 @@ def extract_resource_metadata(resource):
                         {
                             'fields': field['name'],
                             'reference': {
-                                "resource": resource,
-                                "fields": resource_field
+                                "resource": resource.strip(),
+                                "fields": resource_field.strip()
                             }
                         }
                     )
@@ -77,6 +77,8 @@ def ckan_resource_to_frictionless(resource):
     frictionless_resource = converter.resource(resource)
     frictionless_resource['path'] = resource['url']
     frictionless_resource['schema'] = extract_resource_metadata(resource)
+    if 'tableschema' in frictionless_resource:
+        del frictionless_resource['tableschema']
     return frictionless_resource
 
 
